;; Generated package description from orderless.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "orderless" "1.7.0.20260811.5" "Completion style for matching regexps in any order" '((emacs "27.1") (compat "31")) :commit "f4a8114ed729d34d35cec6c7eb34b5d0b23aaa6f" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("matching" "completion") :url "https://github.com/oantolin/orderless")
